@@ -1,6 +1,7 @@
 #ifndef TXTREADER_H
 #define TXTREADER_H
 #include <QApplication>
+#include <QMainWindow>
 #include <QWidget>
 #include <QLabel>
 #include <QList>
@@ -27,23 +28,27 @@
 #include <QUrl>
 #include <QPainter>
 #include "ReaderView.h"
-class TxtReader : public QWidget
+class TxtReader : public QMainWindow//QWidget
 {
 	Q_OBJECT
 public:
-	TxtReader(QWidget * parent = 0,QString infile = "");
+    enum ScreenOrientation {
+        ScreenOrientationLockPortrait,
+        ScreenOrientationLockLandscape,
+        ScreenOrientationAuto
+    };
+        TxtReader(QString infile = "");
         void jumpToPrePage();
         void jumpToNextPage();
+        void setOrientation(ScreenOrientation orientation);
 protected:
 	void keyPressEvent(QKeyEvent * event);
-	void mouseMoveEvent(QMouseEvent *event);
+//	void mouseMoveEvent(QMouseEvent *event);
 	void mousePressEvent(QMouseEvent *event);
         void closeEvent ( QCloseEvent * event );
-	void dragEnterEvent(QDragEnterEvent *event);
-	void dropEvent(QDropEvent *event);
 //for context menu
 	void contextMenuEvent(QContextMenuEvent *event);
-        void paintEvent(QPaintEvent *);
+//        void paintEvent(QPaintEvent *);
         virtual void resizeEvent(QResizeEvent *event);
 private:
 	QString version,bgImage,uilang;
@@ -51,14 +56,11 @@ private:
         QColor txtColor,bgColor;
         int curPageNum,curOffset;
 	bool o_isfullscreen;
+        bool isLandscape;
 
-        QLabel viewTitleLabel;
         ReaderView *viewContentEdit;
-        QLabel viewInstructionLabel;
-        QLabel viewPageLabel;
-        //QSpacerItem *leftSpacer,*rightSpacer;
-        QFrame upLine,bottomLine;
-	QGridLayout *layout;
+        QTimer *showbutton;
+        QTimer *screenblank;
 
         QString FileContent;
         QList<int> PageOffsetList;
@@ -69,14 +71,13 @@ private:
         void jumpToOffset(int offset);
         void jumpToPage(int pageNum);
         int loadFile(const QString &fileName);
-        QString readInstructionContent();
         void genPageList(QString &content,QList<int> &list);
         void reGenPageList();
 
-	QIcon icon;
+        QMenu *fileMenu;
+        QIcon icon;
 	QAction *openAct;
 	QAction *aboutAct;
-	QAction *instructionAct;
 	QString codecstr;
         QMenu *searchMenu;
         QAction *searchOriAct;
@@ -84,6 +85,7 @@ private:
 	QMenu *codecMenu;
 	QAction *GB2312Act;
 	QAction *UTF8Act;
+	QAction *BIG5Act;
 	QActionGroup *codecActionGroup;
 	QAction *jumpAct;
 	QMenu *bookmarkMenu;
@@ -97,25 +99,23 @@ private:
 	QAction *setfontAct;
 	QAction *setfontcolorAct;
 	QMenu * bgMenu;
+	QAction * scnAction;
 	QAction * setbgcolorAct;
 	QAction * setbgimageAct;
 	QAction * delbgimageAct;
-	QMenu * languageMenu;
-	QActionGroup *languageActionGroup;
+        QMenu * historyMenu;
+        QMenu * languageMenu;
+        QActionGroup *languageActionGroup;
 	void createLanguageMenu();
 	QTranslator appTranslator;
 //for trayIcon
 	void createActions();
 	void createTrayIcon();
-	//QAction *maximizeAction;
-	QAction *viewfullscreenAction;
-	QAction *nofullscreenAction;
-	QAction *hiddenAction;
-	QAction *restoreAction;
 	QAction *quitAction;
+        QAction *rotateAct;
 
-	QSystemTrayIcon *trayIcon;
 	QMenu *trayIconMenu;
+        QPushButton *fullButton;
 
 // for recentfiles menu
 	void setCurrentFile(const QString &fileName);
@@ -127,14 +127,13 @@ private:
 	QAction *recentFileActs[MaxRecentFiles];
         QAction *separatorAct;
 
-        void setSizeBaseAndIncIncrement();
+        //void setSizeBaseAndIncIncrement();
         void backToRead();
 private slots:
 	void open();
         void about();
         void slotSearchOri();
         void slotSearchCur();
-        void readOrInstruct();
         void showChanges();
         void myShowContextMenu(QPoint point);
 	void setcodecstr(QAction *action);
@@ -153,14 +152,13 @@ private slots:
 	void setbgimage();
         void resetbg();
 	void hideAndRestore();
-	void myhide();
-	void myrestore();
-	void myshowfullscreen();
-	void myexitfullscreen();
+        void setScreenLight();
+        void screenLight();
 	void switchLanguage(QAction *action);
 	void retranslateUi();
+        void rotate();
+        void touchFull();
 //for trayIcon
-	void iconActivated(QSystemTrayIcon::ActivationReason reason);
 	void quitaction();
 //for recentfiles
         void openRecentFile();
